<?php

declare(strict_types=1);

namespace Borlabs\Cookie\System\Installer\ConsentStatistic;

use Borlabs\Cookie\Adapter\WpDb;
use Borlabs\Cookie\Dto\System\AuditDto;
use Borlabs\Cookie\Repository\ConsentStatistic\ConsentStatisticByHourGroupedByServiceGroupRepository;
use Borlabs\Cookie\Support\Database;

final class ConsentStatisticByHourGroupedByServiceGroupTableMigration
{
    private ConsentStatisticByHourGroupedByServiceGroupInstall $ConsentStatisticByHourGroupedByServiceGroupInstall;

    private ConsentStatisticByHourGroupedByServiceGroupUpgrade $ConsentStatisticByHourGroupedByServiceGroupUpgrade;

    private WpDb $wpdb;

    public function __construct(
        ConsentStatisticByHourGroupedByServiceGroupInstall $ConsentStatisticByHourGroupedByServiceGroupInstall,
        ConsentStatisticByHourGroupedByServiceGroupUpgrade $ConsentStatisticByHourGroupedByServiceGroupUpgrade,
        WpDb $wpdb
    ) {
        $this->ConsentStatisticByHourGroupedByServiceGroupInstall = $ConsentStatisticByHourGroupedByServiceGroupInstall;
        $this->ConsentStatisticByHourGroupedByServiceGroupUpgrade = $ConsentStatisticByHourGroupedByServiceGroupUpgrade;
        $this->wpdb = $wpdb;
    }

    /**
     * @param string $prefix optional; Default: `$wpdb->prefix`; Default prefix for the table name
     */
    public function run(string $prefix = ''): AuditDto
    {
        if (empty($prefix)) {
            $prefix = $this->wpdb->prefix;
        }

        if (Database::tableExists($prefix . ConsentStatisticByHourGroupedByServiceGroupRepository::TABLE) === false) {
            $createStatus = $this->ConsentStatisticByHourGroupedByServiceGroupInstall->createTable($prefix);

            if ($createStatus === false) {
                return new AuditDto(false, $this->wpdb->last_error);
            }
        }

        $upgradeStatus = $this->ConsentStatisticByHourGroupedByServiceGroupUpgrade->upgrade($prefix);

        return new AuditDto($upgradeStatus);
    }
}
